@@ -15,10 +15,16 @@
 # }
 
 markovchainSequence<-function (n, markovchain, t0 = sample(markovchain@states, 1),
-                               include.t0 = FALSE)
+                               include.t0 = FALSE, useRCpp = TRUE)
 {
   if (!(t0 %in% markovchain@states))
     stop("Error! Initial state not defined")
+  
+  # call to cpp implmentation of markovchainSequence
+  if (useRCpp) {
+    return(.markovchainSequenceRcpp(n, markovchain, t0, include.t0))
+  }
+  
   chain <- rep(NA,n)# CHANGED
   state <- t0
   for (i in 1:n) {
@@ -35,24 +41,31 @@ markovchainSequence<-function (n, markovchain, t0 = sample(markovchain@states, 1
 }
 
 
-
 ################
 #random sampler#
 ################
 
+
 #check if the subsequent states are included in the previous ones
 
-.checkSequence<-function(object)
+# TODO: too strong contidion; should be changed by checking that
+# all states that can be reached in one step at t-1 are named  
+# in object[[t]]
+
+.checkSequence <- function(object)
 {
-  out<-TRUE
-  if(dim(object)==1) return(out) #if the size of the list is one do
-  for(i in 2:dim(object))
+  out <- TRUE
+  if (length(object) == 1)
+    return(out) #if the size of the list is one do
+  for (i in 2:length(object))
   {
-    statesNm1<-states(object[[i-1]]) #evalutate mc n.1
-    statesN<-states(object[[i]]) #evaluate mc n
-    intersection<-intersect(statesNm1,statesN) #check the ibntersection
-    if(setequal(intersection, statesNm1)==FALSE) { #the states at n-1 
-      out<-FALSE
+    statesNm1 <- states(object[[i - 1]]) #evalutate mc n-1
+    statesN <- states(object[[i]]) #evaluate mc n
+    intersection <-
+      intersect(statesNm1, statesN) #check the ibntersection
+    if (setequal(intersection, statesNm1) == FALSE) {
+      #the states at n-1
+      out <- FALSE
       break
     }
   }
@@ -60,37 +73,83 @@ markovchainSequence<-function (n, markovchain, t0 = sample(markovchain@states, 1
 }
 
 
-
-rmarkovchain<-function(n,object,what="data.frame",...)
+rmarkovchain <- function(n, object, what = "data.frame", useRCpp = TRUE, ...)
 {
-  if (class(object)=="markovchain") out<-markovchainSequence(n=n, markovchain=object,...)
-  if (class(object)=="markovchainList")
+  if (class(object) == "markovchain")
+    out <- markovchainSequence(n = n, markovchain = object, useRCpp = useRCpp, ...)
+  if (class(object) == "markovchainList")
   {
-    verify <-.checkSequence(object=object)
-    if(!verify) warning("Warning: some states in the markovchain sequences are not contained in the following states!")
-    iteration<-numeric()
-    values<-character()
-    for(i in 1:n) #number of replicates
+    #######################################################
+    if(useRCpp) {
+      include.t0 <- list(...)$include.t0
+      include.t0 <- ifelse(is.null(include.t0), FALSE, include.t0)
+      
+      dataList <- .markovchainListRcpp(n, object@markovchains, include.t0)
+      
+      if (what == "data.frame")
+        out <- data.frame(iteration = dataList[[1]], values = dataList[[2]])
+      else {
+        out <- matrix(data = dataList[[2]], nrow = n, byrow = TRUE)
+        if (what == "list") {
+          outlist <- list()
+          for (i in 1:nrow(out))
+            outlist[[i]] <- out[i, ]
+          out <- outlist
+        }
+      } 
+      return(out)
+    }
+    ##########################################################
+    
+    verify <- .checkSequence(object = object)
+    if (!verify)
+      warning(
+        "Warning: some states in the markovchain sequences are not contained in the following states!"
+      )
+    iteration <- numeric()
+    values <- character()
+    for (i in 1:n)
+      #number of replicates
     {
       #the first iteration may include initial state
-      sampledValues<-markovchainSequence(n=1,markovchain=object[[1]],...)
-      outIter<-rep(i,length(sampledValues))
-      if(dim(object)>1)
-      {for(j in 2:dim(object))
+      sampledValues <-
+        markovchainSequence(n = 1, markovchain = object[[1]], ...)
+      outIter <- rep(i, length(sampledValues))
+      
+      if (length(object) > 1)
       {
-        pos2take<-length(sampledValues)
-        newVals<-markovchainSequence(n=1,markovchain=object[[j]],t0=sampledValues[pos2take]) #the initial state is in the ending position of the mclist
-        outIter<-c(outIter,i)
-        sampledValues<-c(sampledValues,newVals)
+        for (j in 2:length(object))
+        {
+          pos2take <- length(sampledValues)
+          newVals <-
+            markovchainSequence(n = 1,
+                                markovchain = object[[j]],
+                                t0 = sampledValues[pos2take]) #the initial state is in the ending position of the mclist
+          outIter <- c(outIter, i)
+          sampledValues <- c(sampledValues, newVals)
+        }
       }
-      }
-      iteration<-c(iteration, outIter)
-      values<-c(values, sampledValues)
+      iteration <- c(iteration, outIter)
+      values <- c(values, sampledValues)
     }
-    if (what=="data.frame") 
-      out<-data.frame(iteration=iteration, values=values)
+    #defining the output
+    if (what == "data.frame")
+      out <- data.frame(iteration = iteration, values = values)
     else
-      out<-matrix(data=values,nrow=n,byrow=TRUE)
+      #matrix
+    {
+      out <- matrix(data = values,
+                    nrow = n,
+                    byrow = TRUE)
+      if (what == 'list')
+        #or list?
+      {
+        outlist <- list()
+        for (i in 1:nrow(out))
+          outlist[[i]] <- out[i, ]
+        out <- outlist
+      }
+    }
   }
   return(out)
 }
@@ -116,19 +175,28 @@ rmarkovchain<-function(n,object,what="data.frame",...)
 
 #function to fit a DTMC with Laplacian Smoother
 
-.mcFitLaplacianSmooth<-function(stringchar,byrow,laplacian=0.01)
+
+.mcFitLaplacianSmooth <- function(stringchar, byrow, laplacian = 0.01)
 {
-	origNum<-createSequenceMatrix(stringchar=stringchar,toRowProbs=FALSE)
-	sumOfRow<-rowSums(origNum)
-	origDen<-matrix(rep(sumOfRow,length(sumOfRow)),byrow = FALSE,ncol=length(sumOfRow))
-	newNum<-origNum+laplacian
-	newSumOfRow<-rowSums(newNum)
-	newDen<-matrix(rep(newSumOfRow,length(newSumOfRow)),byrow = FALSE,ncol=length(newSumOfRow))
-	transMatr<-newNum/newDen
-	outMc<-new("markovchain", transitionMatrix=transMatr,name="Laplacian Smooth Fit")
-	if(byrow==FALSE) outMc<-t(outMc)
-	out<-list(estimate=outMc)
-	return(out)
+  origNum <-
+    createSequenceMatrix(stringchar = stringchar, toRowProbs = FALSE)
+  newNum <- origNum + laplacian
+  newSumOfRow <- rowSums(newNum)
+  newDen <-
+    matrix(rep(newSumOfRow, length(newSumOfRow)),
+           byrow = FALSE,
+           ncol = length(newSumOfRow))
+  transMatr <- newNum / newDen
+  outMc <-
+    new("markovchain",
+        transitionMatrix = transMatr,
+        name = "Laplacian Smooth Fit")
+
+  if (byrow == FALSE)
+    outMc@transitionMatrix <- t(outMc@transitionMatrix)
+  
+  out <- list(estimate = outMc)
+  return(out)
 }
 
 
@@ -251,7 +319,11 @@ rmarkovchain<-function(n,object,what="data.frame",...)
 #    .Call('markovchain_markovchainFit', PACKAGE = 'markovchain', data, method, byrow, nboot, laplacian, name, parallel, confidencelevel)
 #}
 
-#' Fit a markovchainList
+#' @title markovchainListFit
+#' 
+#' @description  Given a data frame or a matrix (rows are observations, by cols 
+#' the temporal sequence), it fits a non - homogeneous discrete time markov chain 
+#' process (storing row)
 #' 
 #' @param data Either a matrix or a data.frame object.
 #' @param laplacian Laplacian correction (default 0).
@@ -278,21 +350,22 @@ markovchainListFit<-function(data,byrow=TRUE, laplacian=0, name) {
   #otherwise transpose
   if(!byrow) data<-t(data)
   nCols<-ncol(data)
-  #allocate a the list of markovchain
-  markovchains<-list(nCols-1)
+  #allocate a the list of markovchain: a non - homog DTMC process is a 
+  #list of DTMC of length n-1, being n the length of the sequence
+  markovchains<-list() #### allocating #####
   #fit by cols
-  for(i in 2:(nCols)) {
-
+  for(i in 2:(nCols)) { #if whe have at least two transitions
+    # estimate the thransition for period i-1 using cols i-1 and i
     estMc<-.matr2Mc(matrData = data[,c(i-1,i)],laplacian = laplacian)
     if(!is.null(colnames(data))) estMc@name<-colnames(data)[i-1]
-    markovchains[i-1]<-estMc
+    markovchains[[i-1]]<-estMc  #### save this in mc #####
   }
   #return the fitted list
   outMcList<-new("markovchainList",markovchains=markovchains)
   out<-list(estimate=outMcList)
   if(!missing(name)) out$estimate@name<-name
   return(out)
-}
+}  
 
 #' Return MultinomialWise Confidence intervals.
 #' 
